"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (_ref) {
  var t = _ref.types;

  return {
    visitor: {
      ShorthandInstanceExpression: function ShorthandInstanceExpression(path) {
        var node = path.node;
        var expression = node.expression;

        if (t.isAssignmentExpression(expression)) {
          expression.left = t.memberExpression(t.thisExpression(), expression.left);
          path.replaceWith(expression);
        } else if (t.isCallExpression(expression)) {
          expression.callee = t.memberExpression(t.thisExpression(), expression.callee);
          path.replaceWith(expression);
        } else if (t.isIdentifier(expression)) {
          path.replaceWith(t.memberExpression(t.thisExpression(), expression));
        }
      }
    }
  };
};

exports.prepare = prepare;
function prepare(babylon, babelGenerator, babelTypes) {
  babylon.tokTypes.hash = { label: "#", beforeExpr: true };

  var getTokenFromCode = babylon.Parser.prototype.getTokenFromCode;

  babylon.Parser.prototype.getTokenFromCode = function (code) {
    if (code === 35) {
      ++this.state.pos;
      return this.finishToken(babylon.tokTypes.hash);
    }

    return getTokenFromCode.bind(this)(code);
  };

  var parseExprAtom = babylon.Parser.prototype.parseExprAtom;

  babylon.Parser.prototype.parseExprAtom = function (refShorthandDefaultPos) {
    if (this.state.type === babylon.tokTypes.hash) {
      var node = this.startNode();
      this.next();
      node.expression = this.parseExpression();
      return this.finishNode(node, "ShorthandInstanceExpression");
    }

    return parseExprAtom.bind(this)(refShorthandDefaultPos);
  };

  babelGenerator.CodeGenerator.prototype.ShorthandInstanceExpression = function (node) {
    this.push("#");
    this.print(node.expression, node);
  };

  babelTypes.TYPES.push("ShorthandInstanceExpression");
}